## Python package eLABJournal

Source Python package [elabjournal](https://pypi.org/project/elabjournal/)

Install with

```bash
pip install --upgrade elabjournal
```

See [jupyter notebooks](https://github.com/matthijsbrouwer/jupyter-elabjournal) for
a demonstration of functionality.
